==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-core/src/main/java/org/apache/geode/GemFireCacheException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode;

import org.apache.geode.cache.CacheException;

/**
 * An <code>GemFireCacheException</code> is used to wrap a {@link CacheException}. This is needed in
 * contexts that can not throw the cache exception directly because of it being a typed exception.
 */
public class GemFireCacheException extends GemFireException {
  private static final long serialVersionUID = -2844020916351682908L;

  ////////////////////// Constructors //////////////////////

  /**
   * Creates a new <code>GemFireCacheException</code>.
   */
  public GemFireCacheException(String message, CacheException ex) {
    super(message, ex);
  }

  /**
   * Creates a new <code>GemFireCacheException</code>.
   */
  public GemFireCacheException(CacheException ex) {
    super(ex);
  }

  /**
   * Gets the wrapped {@link CacheException}
   */
  public CacheException getCacheException() {
    return (CacheException) getCause();
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/main/java/org/apache/geode/GemFireCacheException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode;

import org.apache.geode.cache.CacheException;

/**
 * An <code>GemFireCacheException</code> is used to wrap a {@link CacheException}. This is needed in
 * contexts that can not throw the cache exception directly because of it being a typed exception.
 */
public class GemFireCacheException extends GemFireException {
  private static final long serialVersionUID = -2844020916351682908L;

  ////////////////////// Constructors //////////////////////

  /**
   * Creates a new <code>GemFireCacheException</code>.
   *
   * @param message the detail message
   * @param ex the cause
   */
  public GemFireCacheException(String message, CacheException ex) {
    super(message, ex);
  }

  /**
   * Creates a new <code>GemFireCacheException</code>.
   *
   * @param ex the cause
   */
  public GemFireCacheException(CacheException ex) {
    super(ex);
  }

  /**
   * Gets the wrapped {@link CacheException}
   *
   * @return the wrapped {@link CacheException}
   */
  public CacheException getCacheException() {
    return (CacheException) getCause();
  }
}
